##############
getwd()
setwd("~/Science/rdata/tax4fun/antarctic_sponges_v2_2019/vegan/")
library(vegan)

#SpongesPooled

# read functions
read.table(file="~/Science/rdata/tax4fun/antarctic_sponges_v2_2019/vegan/sponges_pooled.tsv", check.names=FALSE, row.names=3, header=TRUE,  sep="\t") -> sponges_all
read.table(file="~/Science/rdata/tax4fun/antarctic_sponges_v2_2019/vegan/spongespooledshort.tsv", check.names=FALSE, row.names=3, header=TRUE,  sep="\t") -> sponges_all

sponges_all$level1 <- NULL
sponges_all$level2 <- NULL

as.data.frame(t(sponges_all)) -> sponges_all

#read OTU table
read.csv(file="SpongesPooled.tsv", header=TRUE, row.names=1, sep="\t") -> hab


### ANALYSIS FROM HERE
detach()
attach(hab)

all.abund.vegdist <- vegdist(sponges_all, binary=FALSE, method="bray")


# betadispersion with vegdist
all.abund.site.bdis <- betadisper(all.abund.vegdist, Sponge)
all.abund.site.bdis

plot(all.abund.site.bdis, main="")
boxplot(all.abund.site.bdis, main="")

# betadisper -> permutest = permdisp
all.abund.permu.anov <- permutest(all.abund.site.bdis, pairwise=TRUE)
all.abund.permu.anov

# adonis = permanova
adonis(all.abund.vegdist ~ Sponge, hab, strata=Year,  perm=1000)

# cluster analyse - Bray-Curtis dissimilarity matrix
all.abund.vegdist.clust <- hclust(all.abund.vegdist, method="average")
plot(all.abund.vegdist.clust, las=3, main="")

# nMDS - decostand OTU table
mMDS.abund.all <- metaMDS(sponges_all, distance="bray", k=2, autotransform=FALSE, binary=FALSE)
mMDS.abund.all

#stressplot
stressplot(mMDS.abund.all, main="")

# nMDS plotting
ordiplot(mMDS.abund.all, type="n", main="")
site.scores <- scores(mMDS.abund.all, display="sites")

# plot OTUs
points(mMDS.abund.all, dis="species", pch=19, cex=0.1, col="grey") #OTUs

# plot sites with different colors and shapes
points(site.scores[c(1:2),c(1:2)], bg="firebrick3", cex=1.3, pch=23)
points(site.scores[c(3:4),c(1:2)], bg="dodgerblue3", cex=1.3, pch=23)
points(site.scores[c(5:7),c(1:2)], bg="dodgerblue3", cex=1.3, pch=21)
points(site.scores[c(8:10),c(1:2)], bg="firebrick3", cex=1.3, pch=21)

#SpongesPooledTime

# read functions
read.table(file="~/Science/rdata/tax4fun/antarctic_sponges_v2_2019/vegan/Sponges_Time_Pooled.tsv", check.names=FALSE, row.names=3, header=TRUE,  sep="\t") -> sponges_all

sponges_all$level1 <- NULL
sponges_all$level2 <- NULL

as.data.frame(t(sponges_all)) -> sponges_all

#read OTU table
read.csv(file="SpongesTimePooled.tsv", header=TRUE, row.names=1, sep="\t") -> hab


### ANALYSIS FROM HERE
detach()
attach(hab)

all.abund.vegdist <- vegdist(sponges_all, binary=FALSE, method="bray")


# betadispersion with vegdist
all.abund.site.bdis <- betadisper(all.abund.vegdist, Type)
all.abund.site.bdis

plot(all.abund.site.bdis, main="")
boxplot(all.abund.site.bdis, main="")

# betadisper -> permutest = permdisp
all.abund.permu.anov <- permutest(all.abund.site.bdis, pairwise=TRUE)
all.abund.permu.anov

# adonis = permanova
adonis(all.abund.vegdist ~ Type, hab, strata=Sponge, perm=1000)

